fn layout_in_flow_non_replaced_block_level_same_formatting_context_cached(
layout_context: &LayoutContext<'_>,
positioning_context: &mut PositioningContext,
containing_block: &ContainingBlock<'_>,
sequential_layout_state: Option<&mut SequentialLayoutState>,
collapsible_with_parent_start_margin: Option<CollapsibleWithParentStartMargin>,
ignore_block_margins_for_stretch: LogicalSides1D<bool>,
has_inline_parent: bool,
base: &LayoutBoxBase,
contents: &BlockContainer,
) -> ArcRefCell<BoxFragment>Expand description
Lay out a normal flow non-replaced block that does not establish a new formatting context, properly taking into account relative positioning. This version also handles caching the layout results and fetching the results from the cache, if they are still valid.