pub(crate) struct CollapsibleWithParentStartMargin(bool);Tuple Fields
0: boolTrait Implementations
Sourceimpl Clone for CollapsibleWithParentStartMargin
impl Clone for CollapsibleWithParentStartMargin
Sourcefn clone(&self) -> CollapsibleWithParentStartMargin
fn clone(&self) -> CollapsibleWithParentStartMargin
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl MallocSizeOf for CollapsibleWithParentStartMargin
impl MallocSizeOf for CollapsibleWithParentStartMargin
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl PartialEq for CollapsibleWithParentStartMargin
impl PartialEq for CollapsibleWithParentStartMargin
Sourcefn eq(&self, other: &CollapsibleWithParentStartMargin) -> bool
fn eq(&self, other: &CollapsibleWithParentStartMargin) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for CollapsibleWithParentStartMargin
impl StructuralPartialEq for CollapsibleWithParentStartMargin